@@ -1,6 +1,6 @@
 
 ## BART: Bayesian Additive Regression Trees
-## Copyright (C) 2017 Robert McCulloch and Rodney Sparapani
+## Copyright (C) 2017-2018 Robert McCulloch and Rodney Sparapani
 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -19,23 +19,27 @@
 ## run BART and generate survival in parallel
 
 mc.surv.bart <- function(
-    x.train = matrix(0.0, 0L, 0L),
+    x.train = matrix(0,0,0),
     y.train=NULL, times=NULL, delta=NULL, K=NULL,
-    x.test = matrix(0.0, 0L, 0L),
-    sparse=FALSE, a=0.5, b=1, augment=FALSE, rho=NULL,
-    xinfo=matrix(0.0,0,0), usequants=FALSE,
-    cont=FALSE, rm.const=TRUE, type='pbart',
+    x.test = matrix(0,0,0),
+    sparse=FALSE, theta=0, omega=1,
+    a=0.5, b=1, augment=FALSE, rho=NULL,
+    xinfo=matrix(0,0,0), usequants=FALSE,
+    ##cont=FALSE,
+    rm.const=TRUE, type='pbart',
+    ntype=as.integer(
+        factor(type, levels=c('wbart', 'pbart', 'lbart'))),
     k = 2.0, ## BEWARE: do NOT use k for other purposes below
     power = 2.0, base = 0.95,
-    binaryOffset = NULL,
+    offset = NULL, tau.num=c(NA, 3, 6)[ntype],
+    ##binaryOffset = NULL,
     ntree = 50L, numcut = 100L,
     ndpost = 1000L, nskip = 250L, keepevery = 10L,
-    nkeeptrain=ndpost, nkeeptest=ndpost,
-    ##nkeeptestmean=ndpost,
-    nkeeptreedraws=ndpost,
+    ##nkeeptrain=ndpost, nkeeptest=ndpost,
+    ##nkeeptreedraws=ndpost,
     printevery=100L,
     ##treesaslists=FALSE,
-    keeptrainfits=TRUE,
+    ##keeptrainfits=TRUE,
     id = NULL,     ## only used by surv.bart
     seed = 99L,    ## only used by mc.surv.bart
     mc.cores = 2L, ## ditto
@@ -49,6 +53,9 @@ mc.surv.bart <- function(
     set.seed(seed)
     parallel::mc.reset.stream()
 
+    if(is.na(ntype) || ntype==1)
+        stop("type argument must be set to either 'pbart' or 'lbart'")
+
     x.train <- bartModelMatrix(x.train)
     x.test <- bartModelMatrix(x.test)
 
@@ -59,13 +66,13 @@ mc.surv.bart <- function(
         x.train <- pre$tx.train
         x.test  <- pre$tx.test
 
-        if(length(binaryOffset)==0) binaryOffset <- pre$binaryOffset
+        ##if(length(binaryOffset)==0) binaryOffset <- pre$binaryOffset
     }
     else {
         if(length(unique(sort(y.train)))>2)
             stop('y.train has >2 values; make sure you specify times=times & delta=delta')
 
-        if(length(binaryOffset)==0) binaryOffset <- 0
+        ##if(length(binaryOffset)==0) binaryOffset <- 0
     }
 
     H <- 1
@@ -102,16 +109,19 @@ mc.surv.bart <- function(
         for(i in 1:mc.cores) {
         parallel::mcparallel({psnice(value=nice);
               surv.bart(x.train=x.train, y.train=y.train, x.test=x.test,
-                        sparse=sparse, a=a, b=b, augment=augment, rho=rho,
+                        sparse=sparse, theta=theta, omega=omega,
+                        a=a, b=b, augment=augment, rho=rho,
                         xinfo=xinfo, usequants=usequants,
-                        cont=cont, rm.const=rm.const, type=type,
+                        ##cont=cont,
+                        rm.const=rm.const, type=type,
                         k=k, power=power, base=base,
-                        binaryOffset=binaryOffset,
+                        offset=offset, tau.num=tau.num,
+                        ##binaryOffset=binaryOffset,
                         ntree=ntree, numcut=numcut,
                         ndpost=mc.ndpost, nskip=nskip, keepevery=keepevery,
-                        nkeeptrain=mc.ndpost, nkeeptest=mc.ndpost,
+                        ##nkeeptrain=mc.ndpost, nkeeptest=mc.ndpost,
                         ##nkeeptestmean=mc.ndpost,
-                        nkeeptreedraws=mc.ndpost,
+                        ##nkeeptreedraws=mc.ndpost,
                         printevery=printevery)},
               silent=(i!=1))
               ## to avoid duplication of output
@@ -126,34 +136,40 @@ mc.surv.bart <- function(
         for(h in 1:H) for(i in mc.cores:1) {
             if(h==1 & i==mc.cores) {
                 post <- post.list[[1]][[mc.cores]]
-
+                post$ndpost <- H*mc.cores*mc.ndpost
+                
                 p <- ncol(x.train[ , post$rm.const])
 
-                old.text <- paste0(as.character(mc.ndpost), ' ', as.character(ntree), ' ', as.character(p))
-                ##old.text <- paste0(as.character(mc.nkeep), ' ', as.character(ntree), ' ', as.character(p))
+                old.text <- paste0(as.character(mc.ndpost), ' ',
+                                   as.character(ntree), ' ', as.character(p))
                 old.stop <- nchar(old.text)
 
                 post$treedraws$trees <- sub(old.text,
-                                            paste0(as.character(H*mc.cores*mc.ndpost), ' ', as.character(ntree), ' ',
-                                            ##paste0(as.character(H*mc.cores*mc.nkeep), ' ', as.character(ntree), ' ',
-                                                   as.character(p)),
+                                            paste0(as.character(post$ndpost),
+                                                   ' ', as.character(ntree),
+                                                   ' ', as.character(p)),
                                             post$treedraws$trees)
             }
             else {
-                if(keeptrainfits) {
-                    post$yhat.train <- rbind(post$yhat.train, post.list[[h]][[i]]$yhat.train)
-                    post$prob.train <- rbind(post$prob.train, post.list[[h]][[i]]$prob.train)
-                    ##post$surv.train <- rbind(post$surv.train, post.list[[h]][[i]]$surv.train)
-                }
+                ## if(length(x.test)==0) {
+                ##      post$yhat.train <- rbind(post$yhat.train, post.list[[h]][[i]]$yhat.train)
+                ##      post$prob.train <- rbind(post$prob.train, post.list[[h]][[i]]$prob.train)
+                ##      ##post$surv.train <- rbind(post$surv.train, post.list[[h]][[i]]$surv.train)
+                ## } else {
 
                 if(length(x.test)>0) {
-                    post$yhat.test <- rbind(post$yhat.test, post.list[[h]][[i]]$yhat.test)
-                    post$prob.test <- rbind(post$prob.test, post.list[[h]][[i]]$prob.test)
-                    post$surv.test <- rbind(post$surv.test, post.list[[h]][[i]]$surv.test)
+                    post$yhat.test <- rbind(post$yhat.test,
+                                            post.list[[h]][[i]]$yhat.test)
+                    post$prob.test <- rbind(post$prob.test,
+                                            post.list[[h]][[i]]$prob.test)
+                    post$surv.test <- rbind(post$surv.test,
+                                            post.list[[h]][[i]]$surv.test)
                 }
 
-                post$varcount <- rbind(post$varcount, post.list[[h]][[i]]$varcount)
-                post$varprob <- rbind(post$varprob, post.list[[h]][[i]]$varprob)
+                post$varcount <- rbind(post$varcount,
+                                       post.list[[h]][[i]]$varcount)
+                post$varprob <- rbind(post$varprob,
+                                      post.list[[h]][[i]]$varprob)
 
                 post$treedraws$trees <- paste0(post$treedraws$trees,
                                                substr(post.list[[h]][[i]]$treedraws$trees, old.stop+2,
@@ -161,6 +177,12 @@ mc.surv.bart <- function(
 
                 ## if(treesaslists) post$treedraws$lists <-
                 ##                      c(post$treedraws$lists, post.list[[h]][[i]]$treedraws$lists)
+
+                post$proc.time['elapsed'] <- max(post$proc.time['elapsed'],
+                                                 post.list[[h]][[i]]$proc.time['elapsed'])
+                for(j in 1:5)
+                    if(j!=3)
+                        post$proc.time[j] <- post$proc.time[j]+post.list[[h]][[i]]$proc.time[j]
             }
 
             post.list[[h]][[i]] <- NULL
