@@ -134,42 +134,11 @@ void bart::draw(double sigma, rn& gen)
       fit(t[j],xi,p,n,x,ftemp);
       for(size_t k=0;k<n;k++) allfit[k] += ftemp[k];
    }
-   if(dartOn) draw_s(gen);
-}
-//--------------------------------------------------
-void bart::draw_s(rn& gen)
-{
-  // Draw sparsity parameter alpha as described in Linero, 2016
-  // spars / (spars + rho ) ~ Be(a,b)
-  // Set (a,b) to (.5,1) for sparsity
-  // Set (a,b) to (1,1) for non-sparsity
-  // rho = p usually, but making rho < p increases sparsity
-  double spars,beta;
-  gen.set_beta(a, b);
-  beta=gen.beta();
-  spars=(beta*rho/(1-beta))/(double)p;
-  // Now draw s, the vector of splitting probabilities
-  std::vector<double> _alpha(p);
-  for(size_t j=0;j<p;j++) _alpha[j]=spars+nv[j];
-  gen.set_alpha(_alpha);
-  pv=gen.dirichlet();
-/*
-  double x1,x2,beta,gsum;
-  gen.set_shape(a);
-  x1=gen.gamma();
-  gen.set_shape(b);
-  x2=gen.gamma();
-  beta=x1/(x1+x2);
-  spars=beta*rho/(1-beta);
-  // Now draw s, the vector of splitting probabilities
-  gsum=0;
-  for(size_t j=0;j<p;j++){
-    gen.set_shape(spars/(double)p+nv[j]);
-    pv[j]=gen.gamma();
-    gsum+=pv[j];
-  }
-  for(size_t j=0;j<p;j++) pv[j]=pv[j]/gsum;
-*/
+   if(dartOn) {
+     draw_s(nv,lpv,theta,gen);
+     draw_theta0(const_theta,theta,lpv,a,b,rho,gen);
+     for(size_t j=0;j<p;j++) pv[j]=::exp(lpv[j]);
+   }
 }
 //--------------------------------------------------
 //public functions
